@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Async::Scroll;
-$Search::Elasticsearch::Async::Scroll::VERSION = '1.99';
+$Search::Elasticsearch::Async::Scroll::VERSION = '2.00';
 use Moo;
 use Search::Elasticsearch::Util qw(parse_params throw);
 use Search::Elasticsearch::Async::Util qw(thenable);
@@ -174,29 +174,35 @@ sub _results_iterator {
 }
 
 #===================================
-sub _clear_scroll {
+sub finish {
 #===================================
     my $self = shift;
-    my $scroll_id = $self->_scroll_id or return;
+    $self->_set_is_finished(1);
+
+    my $scroll_id = $self->_scroll_id;
     $self->_clear_scroll_id;
 
+    if ( !$scroll_id || $self->_pid != $$ ) {
+        my $d = deferred;
+        $d->resolve();
+        return $d->promise;
+    }
+
     my %args
         = $self->scroll_in_qs
         ? ( scroll_id => $scroll_id )
         : ( body => $scroll_id );
 
-    $self->es->clear_scroll(%args)->catch( sub { } );
+    $self->es->clear_scroll(%args)->then(
+        sub {
+            $self->_clear_on_start;
+            $self->_clear_on_results;
+            $self->_clear_on_error;
+        },
+        sub { }
+    );
 }
 
-#===================================
-after 'finish' => sub {
-#===================================
-    my $self = shift;
-    $self->_clear_on_start;
-    $self->_clear_on_results;
-    $self->_clear_on_error;
-};
-
 1;
 
 # ABSTRACT: A helper module for scrolled searches
@@ -213,7 +219,7 @@ Search::Elasticsearch::Async::Scroll - A helper module for scrolled searches
 
 =head1 VERSION
 
-version 1.99
+version 2.00
 
 =head1 SYNOPSIS
 
@@ -261,14 +267,14 @@ until there are no more matching results, much like a cursor in an SQL
 database.
 
 Unlike paginating through results (with the C<from> parameter in
-L<search()|Search::Elasticsearch::Client::1_0::Direct/search()>),
+L<search()|Search::Elasticsearch::Client::2_0::Direct/search()>),
 scrolled searches take a snapshot of the current state of the index. Even
 if you keep adding new documents to the index or updating existing documents,
 a scrolled search will only see the index as it was when the search began.
 
 This module is a helper utility that wraps the functionality of the
-L<search()|Search::Elasticsearch::Client::1_0::Direct/search()> and
-L<scroll()|Search::Elasticsearch::Client::1_0::Direct/scroll()> methods to make
+L<search()|Search::Elasticsearch::Client::2_0::Direct/search()> and
+L<scroll()|Search::Elasticsearch::Client::2_0::Direct/scroll()> methods to make
 them easier to use.
 
 B<IMPORTANT>: Deep scrolling can be expensive.  See L</DEEP SCROLLING>
@@ -410,14 +416,14 @@ are memory constrained, you will need to take this into account.
     );
     $scroll->start;
 
-The L<Search::Elasticsearch::Client::1_0::Direct/scroll_helper()> method loads
+The L<Search::Elasticsearch::Client::2_0::Direct/scroll_helper()> method loads
 L<Search::Elasticsearch::Async::Scroll> class and calls L</new()>,
 passing in any arguments.
 
 You can specify a C<scroll> duration (which defaults to C<"1m">),
 C<scroll_in_qs> (which defaults to C<false>), and any
 of the listed callbacks. Any other parameters are
-passed directly to L<Search::Elasticsearch::Client::1_0::Direct/search()>.
+passed directly to L<Search::Elasticsearch::Client::2_0::Direct/search()>.
 
 The C<scroll> duration tells Elasticearch how long it should keep the scroll
 alive.  B<Note>: this duration doesn't need to be long enough to process
@@ -426,7 +432,7 @@ The expiry gets renewed for another C<scroll> period every time new
 a new batch of results is retrieved from the cluster.
 
 By default, the C<scroll_id> is passed as the C<body> to the
-L<scroll|Search::Elasticsearch::Client::1_0::Direct/scroll()> request.
+L<scroll|Search::Elasticsearch::Client::2_0::Direct/scroll()> request.
 To send it in the query string instead, set C<scroll_in_qs> to a true value,
 but be aware: when querying very many indices, the scroll ID can become
 too long for intervening proxies.
@@ -557,9 +563,9 @@ This value can only be checked once the scroll has completed.
 
 =item * L<Search::Elasticsearch::Async::Bulk/reindex()>
 
-=item * L<Search::Elasticsearch::Client::1_0::Direct/search()>
+=item * L<Search::Elasticsearch::Client::2_0::Direct/search()>
 
-=item * L<Search::Elasticsearch::Client::1_0::Direct/scroll()>
+=item * L<Search::Elasticsearch::Client::2_0::Direct/scroll()>
 
 =back
 
