@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Cxn::Async;
-$Search::Elasticsearch::Role::Cxn::Async::VERSION = '1.99';
+$Search::Elasticsearch::Role::Cxn::Async::VERSION = '2.00';
 use Moo::Role;
 
 use Search::Elasticsearch::Util qw(new_error);
@@ -38,7 +38,7 @@ sub sniff {
     $self->perform_request(
         {   method  => 'GET',
             path    => '/_nodes/' . $protocol,
-            qs      => { timeout => 1000 * $self->sniff_timeout },
+            qs      => { timeout => $self->sniff_timeout . 's' },
             timeout => $self->sniff_request_timeout,
         }
         )->then(
@@ -66,7 +66,7 @@ Search::Elasticsearch::Role::Cxn::Async - Provides common functionality to async
 
 =head1 VERSION
 
-version 1.99
+version 2.00
 
 =head1 DESCRIPTION
 
